# Module overview
This module integrates with DUO MFA to get temporary access for aws
##Installation and execution
To install this package, please run the below command on your console.

```
pip install aws-access
```
This will install the package along with all its dependencies.
Once installed, execute the package using the below command

```
python -m aws_access_util.get_aws_access --awsurl <url> --u <user> --dur <duration> --p <password>

url: This is the url of the AWS account
user: The userid to connect to the URL
password: The password to connect to the URL
dur: The duration in seconds for which access is required. Deafult is 1 hour
```
If none of the parameters are given, the utility will prompt for the value 
of the parameters except for duration(--dur). It will take default duration of 1 hour

##Help information

To find out how to use the utility, you can execute the below command

``` 
python -m aws_access_util.get_aws_access --help

usage: get_aws_access.py [-h] [--awsurl URL] [--u USER] [--p PASSWORD]
                         [--dur DURATION_SECONDS]

Retrieves and stores a temporary token which is used to access AWS resource

optional arguments:
  -h, --help            show this help message and exit
  --awsurl URL          Specify a valid aws url
  --u USER              Specify your userid
  --p PASSWORD          Specify your password
  --dur DURATION_SECONDS
                        Specify duration in seconds for which you need
                        access.Must be > 900 and less than 43200. Default is 1
                        hour or 3600 secs.
```

##Authors

* **Rajib Deb** - *Initial Work* - [Cisco](rajdeb@cisco.com)